// JBPlayer.uc
// just to let the gameinfo know who killed us so we can go to jail or whatnot.
class JBPlayer extends xMpPlayer;

const MAX_RELEASES=32;

var Controller OurLastKillerController;
var bool bSpawnAsMadCow;
var bool bIsMadCow;
var ReleaseProtection OurReleaseProtection;
var int ProtectedDamageDealt;

var array<JailRelease> JailReleases[MAX_RELEASES];
var array<int> ClientReleaseDependency[MAX_RELEASES];

replication
{
	// functions server can send to the client
	reliable if (Role == ROLE_Authority)
		ClientWatchExecution, ClientSpectate, JailReleases, ClientReleaseDependency;

	// functions client can send to the server
	reliable if (Role < ROLE_Authority)
		ServerCancelReleaseProtection;
}

// Server tells client where all the jail releases are.
simulated function PostBeginPlay()
{
	Super.PostBeginPlay();
	InitReleases();
}

simulated function InitReleases()
{
	local int i;
	local JailRelease tt;

	i = 0;
	foreach DynamicActors(class'JailRelease', tt)
	{
		JailReleases[i]=tt;
		i++;
		if (i >= MAX_RELEASES)
			break;
	}
}

function int CountPawnsIn(array<Name> ZoneTags)
{
	local int i,j;
	local TeamInfo OurTeam;
	local Controller C;

	OurTeam = PlayerReplicationInfo.Team;

	j=0;
	for (i=0; i<ZoneTags.Length; i++)
		for (C=Level.ControllerList; C!=None; C=C.NextController)
			if (C.PlayerReplicationInfo.Team == OurTeam && C.PlayerReplicationInfo.PlayerZone != None)
				if (String(C.PlayerReplicationInfo.PlayerZone.Tag) ~= String(ZoneTags[i]))
					j++;

	return j;
}

//
function UpdateReleases()
{
	local int i;
	local JailRelease tt;

	if (Role == ROLE_Authority)	
		for (i=0; i<MAX_RELEASES; i++)
			if (JailReleases[i] != None)
				ClientReleaseDependency[i] = CountPawnsIn(JailReleases[i].JailZoneTags);
}

// When reset, remove the lastkillercontroller so we don't wind up back in jail in the next round.
function Reset()
{
	OurLastKillerController = None;
	Super.Reset();
	if (PlayerReplicationInfo.bOnlySpectator)
		ClientSpectate();
}

// Force the client to go to WatchingExecution state.
simulated function ClientWatchExecution(Actor ExecutionCamera)
{
	SetViewTarget(ExecutionCamera);
	GotoState('WatchingExecution');
}

simulated function ClientSpectate()
{
	GotoState('Spectating');
	ServerViewSelf();
}

// Sets up release protection.
// Would rather do this in a pawn class but we can't what with all the different pawn classes for each character
function SetupReleaseProtection(float ProtectionTime)
{
	if (OurReleaseProtection == None && ProtectionTime > 0)
	{
		OurReleaseProtection=spawn(class'ReleaseProtection',Self);
		OurReleaseProtection.SetTimer(ProtectionTime, false);
	}
}

// Tell the server we've fired our weapon and we don't want release protection anymore.
function ServerCancelReleaseProtection()
{
	if (Role == ROLE_Authority)
		if (OurReleaseProtection != None)
			OurReleaseProtection.Destroy();
}

exec function Fire(optional float F)
{
	ServerCancelReleaseProtection();
	Super.Fire(F);
}

exec function AltFire(optional float F)
{
	ServerCancelReleaseProtection();
	Super.AltFire(F);
}

exec function Aneurism()
{
	if (JailZone(PlayerReplicationInfo.PlayerZone) == None)
		Super.Aneurism();
	else
		ClientMessage("No suicides allowed in jail!");
}

exec function Suicide()
{
	if (JailZone(PlayerReplicationInfo.PlayerZone) == None)
		Super.Suicide();
	else
		ClientMessage("No suicides allowed in jail!");
}

exec function Taunt(name Sequence); // Stubbed out to prevent removing cow head with burnme cheat

// prevent people from doing anything "funny" during the execution
state WatchingExecution
{
ignores SeePlayer, HearNoise, KilledBy, NotifyBump, HitWall, ActivateInventoryItem, Jump, ThrowWeapon,
		ThrowPowerup, PrevInvItem, NextInvItem, ActivateItem, NotifyHeadVolumeChange, 
		NotifyPhysicsVolumeChange, Falling, CheckMapReminder, SwitchWeapon,
		DamageAttitudeTo, Suicide, UseZipper, DudeShoutGetDown, ToggleInvHints, ToggleToHands,
		QuickUseMap, DoKick, QuickSave, CanBeMugged, WeaponZoom, WeaponZoomIn, WeaponZoomOut,
		IsSaveAllowed, ReadyForCashier, ExitSnipingState, ExitPrepToSave, SetupGettingMugged, PlayerMove,
		AskForPawn;
}

state Spectating
{
	function BeginState()
	{
		Super.BeginState();
		bCollideWorld=false; // lets spectators "walk" through walls
	}
}

state PlayerWalking
{
	event BeginState()
	{
		Super.BeginState();
		SetTimer(1, true);
	}
	event Timer()
	{
		UpdateReleases();
		Super.Timer();
	}
}

defaultproperties
{
	PlayerReplicationInfoClass=Class'P2JailBreak.JBPlayerReplicationInfo'
}