// JailBreakGame.uc
// The brains of P2JailBreak
class JailBreakGame extends TeamGame;

struct MadCowPrizeStruct
{
	var config class<P2PowerupInv> PrizeClass;
	var config float Chance;
};

var() string MadCowHeadMesh;
//var config float WaitForNextRound;
var() config bool bUseMadCow;
var() config bool bJailCampMadCow;
var() config int JailCampThreshold;
var() config int JailCampWarning;
var() config float MadCowHuntDuration;
var() config array<MadCowPrizeStruct> MadCowPrizes;
var() config float ReleaseProtectionDuration;

//var float WaitNextRoundTime;
var float MadCowHuntStartTime;

var int NumPawnsJailed[2];
var int NumMadCowsActive;

var ExecutionCamera ExecCamera;
var name ExecTag;
var TeamInfo ScoringTeam, DyingTeam;
var PlayerReplicationInfo EndGameScorer;
var Controller LastKiller, LastKilled;
var GibTimer OurGibber;

var array<String> JoinedAddresses; // list of addresses so we can check for players reconnecting

// Check to see if a player is in the "mad cow list", and optionally add them
function bool CheckForMadCow(PlayerController P, bool AddEm)
{
	local string s;
	local int i;
	local bool b;

	S = P.GetPlayerNetworkAddress();
	s = left(s,instr(s,":"));
	//log("Checking"@S@"against the list of IPs who were jailed before... AddEm is"@Addem);
	for (i=0; i<JoinedAddresses.Length; i++)
		if (JoinedAddresses[i] ~= S)
		{
			b = true;
			break;
		}
	//if (b)
		//log("Found it!");
	if (!b && AddEm)
	{
		//log("Didn't find it, but adding to the list");
		JoinedAddresses.Insert(0,1);
		JoinedAddresses[0] = S;
	}
	//else
		//log("Didn't find it, and not adding it to the list");

	return b;
}

// Remove a player from the "mad cow list"
function RemoveFromMadCowList(PlayerController P)
{
	local string s;
	local int i;
	local bool b;

	S = P.GetPlayerNetworkAddress();
	s=left(s,instr(s,":"));
	//log("Removing"@S@"from the list of IPs who were jailed before...");
	for (i=0; i<JoinedAddresses.Length; i++)
		if (JoinedAddresses[i] ~= S)
		{
			b = true;
			JoinedAddresses.Remove(i,1);
			break;
		}
}

// MadCow Disease
// If anyone rejoins to escape jail, make them catch MadCow disease
event PostLogin(PlayerController NewPlayer, string Options)
{
	Super.PostLogin(NewPlayer, Options);

	if (JBPlayer(NewPlayer) != None)
		JBPlayer(NewPlayer).bSpawnAsMadCow=CheckforMadCow(NewPlayer, False);
}

// when someone with madcow spawns, give them a madcow head
function RestartPlayer(Controller aPlayer)
{
	local bool bMakeMadCow;

	Super.RestartPlayer(aPlayer);

	if (bUseMadCow)
	{
		if (JBPlayer(aPlayer) != None && aPlayer.Pawn != None)
		{
			if (JBPlayer(aPlayer).bSpawnAsMadCow && MpPawn(aPlayer.Pawn) != None)
			{
				ConvertToMadCow(MpPawn(aPlayer.Pawn));
				JBPlayer(aPlayer).bSpawnAsMadCow=false;
			}
			else
			{
				JBPlayer(aPlayer).bIsMadCow=false;
				JBPlayerReplicationInfo(aPlayer.PlayerReplicationInfo).bIsMadCow=false;
			}
	
			RemoveFromMadCowList(PlayerController(aPlayer));
		}
	}
}

// convert this guy to a madcow head
// also start the madcow hunt if there is none in progress
function ConvertToMadCow(MpPawn Other)
{
	local int i;
	local StaticMesh foo;

	// madcow is done as a bolton, you can't see the "regular" head with the cowhead covering it
	foo = StaticMesh(DynamicLoadObject(MadCowHeadMesh, class'StaticMesh'));
	//Other.HeadSkin = MadCowHeadSkin;
	//Other.HeadMesh = MadCowHeadMesh;
	//Other.DestroyHead();
	//Other.SetupHead();

	for (i=0; i < Other.MAX_BOLTONS; i++)
		if (Other.boltons[i].part == None)
		{
			Other.boltons[i].part = spawn(class'PeoplePart');
			Other.boltons[i].part.SetStaticMesh(foo);
			Other.boltons[i].part.SetDrawType(DT_StaticMesh);
			Other.boltons[i].bCanDrop = false;
			Other.boltons[i].bAttachToHead = true;
			if (Other.boltons[i].part != None)
			{
				Other.MyHead.AttachToBone(Other.boltons[i].part, 'NODE_parent');
				Other.Boltons[i].Part.bAlwaysRelevant = true;
				break;
			}
		}

	// Tell the player they've caught mad cow disease
	if (JBPlayer(Other.Controller) != None)
	{
		PlayerController(Other.Controller).ReceiveLocalizedMessage(class'MadCowMessage', 0);
		JBPlayer(Other.Controller).bIsMadCow=true;
		JBPlayerReplicationInfo(Other.PlayerReplicationInfo).bIsMadCow=true;
	}

	NumMadCowsActive++;

	if (MadCowHuntStartTime == 0)
	{
		// Start the MadCow Hunt!
		MadCowHuntStartTime = Level.TimeSeconds;
		BroadcastLocalizedMessage(class'JailMessage', 4);
		BroadcastLocalizedMessage(class'MadCowMessage', 1);
	}
}

// Give 'em a bunch of cool stuff
function GrantMadCowBonus(Controller Killer)
{
	local P2Pawn P;
	local class<Powerups> pclass;
	local class<P2PowerupPickup> pick;
	local P2PowerupInv p2inv;
	local byte CreatedNow;
	local int i;

	// Let everyone know that we've caught a madcow!
	BroadcastLocalizedMessage(class'JailMessage', 5, Killer.PlayerReplicationInfo);

	if (P2Pawn(Killer.Pawn) == None)
		return;
	if (P2Player(Killer) == None)
		return;

	P = P2Pawn(Killer.Pawn);

	for (i=0; i<MadCowPrizes.Length; i++)
	{
		if (frand() < MadCowPrizes[i].Chance)
		{
			CreatedNow = 0;
			p2inv = P2PowerupInv(P.CreateInventoryByClass(MadCowPrizes[i].PrizeClass,CreatedNow));
			if(p2inv != None && CreatedNow == 0)
			{
				pick = class<P2PowerupPickup>(p2inv.PickupClass);
				p2inv.AddAmount(pick.default.AmountToAdd);
			}
		}
	}
}

// Let madcows take damage no matter what.
// Copied from 1409 TeamGame.uc
function int ReduceDamage( int Damage, pawn injured, pawn instigatedBy, vector HitLocation, out vector Momentum, class<DamageType> DamageType )
{
	local TeamInfo InjuredTeam, InstigatorTeam;
	local bool bMadCow;
	local bool bTargetProtected;

	if ( instigatedBy == None )
		return Super.ReduceDamage( Damage,injured,instigatedBy,HitLocation,Momentum,DamageType );

	if (JBPlayer(Injured.Controller) != None)
	{
		bMadCow=JBPlayer(Injured.Controller).bIsMadCow;
		if (JBPlayer(Injured.Controller).OurReleaseProtection != None)
			bTargetProtected=true;
	}

	InjuredTeam = Injured.GetTeam();
// Originally bIgnoreTeams was implemented because at the office we didn't like friendlyfire, 
// but we felt like splash damaged weapons like grenades and anthrax should hurt everyone. 
// We put this check in so that even with FriendlyFire at 0, you still hurt someone with
// a rocket. Big mistake.. because that let the asshole teamkillers to run around and harass
// people on servers trying to play legitimate games. In the end, we're taking it out
// and linking splash damage *and* bullet damage weapons to the FriendlyFire slider. 
// Now if it's at 0, nothing hurts your teammate, but at 100, all weapons hurt
// with 100% damage, and so forth. 
//	if(class<P2Damage>(DamageType) == None)
//		|| !class<P2Damage>(DamageType).default.bIgnoreTeams)
	if (!bMadCow) // Kamek's addition
		InstigatorTeam = InstigatedBy.GetTeam();
	if ( instigatedBy != injured )
	{
		if ( (InjuredTeam != None) && (InstigatorTeam != None) )
		{
			if ( InjuredTeam == InstigatorTeam )
			{
				// We like the momentum to be the same on either side regardless of teams kills/not
				//Momentum *= 0.3;
				if ( Bot(injured.Controller) != None )
					Bot(Injured.Controller).YellAt(instigatedBy);
				if ( FriendlyFireScale==0.0 )
				{
					if ( GameRulesModifiers != None )
						return GameRulesModifiers.NetDamage( Damage, 0,injured,instigatedBy,HitLocation,Momentum,DamageType );
					else
						return 0;
				}
				Damage *= FriendlyFireScale;
			}
			else if ( !injured.IsHumanControlled() && (injured.Controller != None)
					&& (injured.PlayerReplicationInfo != None) && (injured.PlayerReplicationInfo.HasFlag != None) )
				injured.Controller.SendMessage(None, 'OTHER', injured.Controller.GetMessageIndex('INJURED'), 15, 'TEAM');
		}
	}

	if (bJailCampMadCow && bTargetProtected && JBPlayer(InstigatedBy.Controller) != None)
	{
		JBPlayer(InstigatedBy.Controller).ProtectedDamageDealt += Damage;
		if (JBPlayer(InstigatedBy.Controller).ProtectedDamageDealt > JailCampThreshold && MpPawn(InstigatedBy) != None && !JBPlayer(InstigatedBy.Controller).bIsMadCow)
		{
			ConvertToMadCow(MpPawn(InstigatedBy));
			JBPlayer(InstigatedBy.Controller).ProtectedDamageDealt = 0;
		}
		else if (Damage > JailCampWarning) // warn them
			PlayerController(InstigatedBy.Controller).ReceiveLocalizedMessage(class'MadCowMessage', 2);
	}

	// We copied the code from TeamGame so call Super(DeathMatch) to skip the same coding in TeamGame.
	return Super(DeathMatch).ReduceDamage( Damage,injured,instigatedBy,HitLocation,Momentum,DamageType );
}

// used to find the best possible execution camera view
function int CountVisiblePawns(actor A)
{
	local int NumPawns;
	local MpPawn P;

	NumPawns=0;
	ForEach A.VisibleActors(class'MpPawn', P)
		if (P.Health > 0)
			NumPawns++;

	return NumPawns;
}

// Returns a good viewpoint for watching the team's execution
function ExecutionCamera GetExecutionCamera(TeamInfo DyingTeam)
{
	local Array<ExecutionCamera> Cams;
	local ExecutionCamera EC;
	local int i, j;
	local int VisiblePawns;

	// Look through all execution cameras or keypoints with a matching tag
	// ExecutionCamera is just a regular Keypoint with bDirectional defaulting to true
	foreach AllActors(class'ExecutionCamera', EC)
	{
		if (EC.Team == DyingTeam.TeamIndex)
		{
			Cams.Insert(0,1);
			Cams[0]=EC;
		}
	}

	// No cameras found
	if (Cams.Length <= 0)
	{
		warn("No ExecutionCameras found!");
		return None;
	}

	// now see which camera is "best" to watch the carnage
	EC = None;
	VisiblePawns = 0;
	for (i=0; i<Cams.Length; i++)
	{
		j = CountVisiblePawns(Cams[i]);
		if (j > VisiblePawns)
		{
			EC = Cams[i];
			VisiblePawns = j;
		}
	}

	// Can't see anyone at all!
	if (VisiblePawns == 0)
	{
		//warn("No pawns are visible to any available execution camera!");
		EC = Cams[0];
	}

	return EC;
}

// Spawn people in the jail after they die
// Don't let new people spawn in the jail
function float RatePlayerStart(NavigationPoint N, byte Team, Controller Player)
{
	local PlayerStart P;
	local JailStart J;
	local bool bShouldJail;
	local bool bFoo;

	P = PlayerStart(N);
	J = JailStart(N);

	// If this is not a playerstart, fail
	if ( P == None )
		return -10000000;

	// If someone just killed us, we should go to jail.
	if ( JBPlayer(Player) != None )
		if ( JBPlayer(Player).OurLastKillerController != None )	
			bShouldJail=true;

	// If we're a bot and we have a positive number of deaths, we should go to jail.
	// Bot deaths are reset to 0 after each execution. *HACK*
	if ( Bot(Player) != None )
		if ( Player.PlayerReplicationInfo.Deaths > 0 )
			bShouldJail=true;

	// If they need to go to jail, send them there.
	if (bShouldJail)
	{
		// If this is not a jailstart, fail
		if (J == None)
			return -10000000;

		// If this jailstart is in the wrong jail, fail
		else if ( Team != J.TeamNumber )
			return -9000000;
	}
	else // normal spawning
	{
		// Don't let them spawn in jail
		if (J != None)
			return -10000000;

		// If the gamerules specify spawning in team area, and this is the wrong team, don't let em use it
		if (bSpawnInTeamArea && (Team != P.TeamNumber))
			return -9000000;
	}

	// otherwise treat this as a valid playerstart according to Super
	return Super.RatePlayerStart(N,Team,Player);
}

// Called by JailZone
function PawnJailed(Pawn Other)
{
	// Don't count up jailed pawns here anymore, do it in Timer

	/*local TeamInfo T;

	T = Other.GetTeam();
	NumPawnsJailed[T.TeamIndex]++;
	//log(Other@"was jailed, to make a total of"@NumPawnsJailed[T.TeamIndex]@"out of"@T.Size@"on team"@T);
	if (NumPawnsJailed[T.TeamIndex] >= T.Size)
		ExecutionEvent(T, Other);*/

	// but do add them to the "mad cow list"
	if (PlayerController(Other.Controller) != None)
		CheckForMadCow(PlayerController(Other.Controller), True);
}

// Also called by JailZone
function PawnUnJailed(Pawn Other)
{
	/*local int T;

	T = Other.GetTeam().TeamIndex;
	NumPawnsJailed[T]--;
	//log(Other@"left jail, to make a total of"@NumPawnsJailed[T]@"jailed");*/
}

// Team scores, start up the execution!
function ExecutionEvent(TeamInfo T, Pawn Other)
{
	local Pawn KillingPawn;
	local ExecutionTrigger ET;

	// DyingTeam is the team getting executed
	DyingTeam = T;

	// ScoringTeam is the team getting a point
	ScoringTeam = Level.Game.GameReplicationInfo.Teams[1-T.TeamIndex];

	// trigger execution here
	OurGibber=spawn(class'GibTimer');
	if (DyingTeam.TeamIndex == 0)
	{
		TriggerEvent(JBGameRules(LevelRules).ExecutionEventRed, DyingTeam, Other);
		OurGibber.StartGibTimer(DyingTeam, JBGameRules(LevelRules).BackupGibbingRed);
	}
	if (DyingTeam.TeamIndex == 1)
	{
		TriggerEvent(JBGameRules(LevelRules).ExecutionEventBlue, DyingTeam, Other);
		OurGibber.StartGibTimer(DyingTeam, JBGameRules(LevelRules).BackupGibbingRed);
	}

	ExecCamera = GetExecutionCamera(DyingTeam);

	// try to find out who killed this guy
	if (JBPlayer(Other.Controller) != None)
		KillingPawn = JBPlayer(Other.Controller).OurLastKillerController.Pawn;

	// we don't know who killed this guy, so assume it was the last person to make a kill.
	if (KillingPawn == None && LastKiller != None && LastKilled.Pawn == Other)
		KillingPawn = LastKiller.Pawn;

	// we still don't know who killed this guy, assume it was a suicide
	if (KillingPawn == None)
		KillingPawn = Other;

	// tell the whole world
	if (KillingPawn == None) // we STILL don't know who killed this guy, so just play a scoring message
		BroadcastLocalizedMessage(class'JailMessage',3,KillingPawn.PlayerReplicationInfo,None,ScoringTeam);
	else if (KillingPawn.GetTeam() != ScoringTeam) // scored for the enemy team!
		BroadcastLocalizedMessage(class'JailMessage',2,KillingPawn.PlayerReplicationInfo,None,ScoringTeam);
	else // normal scoring event
		BroadcastLocalizedMessage(class'JailMessage',0,KillingPawn.PlayerReplicationInfo,None,ScoringTeam);

	// don't score the point here, we want to see the execution first
	EndGameScorer = KillingPawn.PlayerReplicationInfo;
	GotoState('Executing');
}

// let the JBPlayer know who our last killer was
function ScoreKill(Controller Killer, Controller Other)
{
	if (GetStateName() == 'Executing')
		return;

	if (JBPlayer(Other) != None)
	{
		if (Killer == None)
			JBPlayer(Other).OurLastKillerController = Other;
		else
			JBPlayer(Other).OurLastKillerController = Killer;

		if (JBPlayer(Other).bIsMadCow)
		{
			NumMadCowsActive--;
			if (Killer != None)
				if (Other != Killer && MadCowHuntStartTime != 0)
					GrantMadCowBonus(Killer);
		}
	}

	LastKiller = Killer;
	LastKilled = Other;

	Super.ScoreKill(Killer, Other);
}

state MatchInProgress
{
	event Timer() // do a bunch of jailbreak-related shizzle, yo
	{
		local Controller C;
		local Pawn P;

		// Count up the number of pawns who are jailed
		NumPawnsJailed[0]=0;
		NumPawnsJailed[1]=0;

		C=Level.Controllerlist;
		while (C != None)
		{
			if (JailZone(C.PlayerReplicationInfo.PlayerZone) != None && C.PlayerReplicationInfo.Team != None)
				if (C.Pawn != None)
				{
					P = C.Pawn;
					if (P.Health > 0)
						NumPawnsJailed[C.PlayerReplicationInfo.Team.Teamindex]++;
				}
			if (JailZone(C.PlayerReplicationInfo.PlayerZone) == None && PlayerController(C) != None && C.Pawn != None)
				RemoveFromMadCowList(PlayerController(C));

			C=C.NextController;
		}

		if (GetStateName()!='Executing') // force respawns
		{
			// Do this FIRST, so the people who just died can go to jail BEFORE the execution starts
			For ( C=Level.ControllerList; C!=None; C=C.NextController )
			{
				if ( (C.Pawn == None) && C.IsA('PlayerController') && !C.PlayerReplicationInfo.bOnlySpectator )
				{
					if (MpPlayer(C) != None && MpPlayer(C).CanRestartPlayer()) // && JBPlayer(C).OurLastKillerController != None)
						PlayerController(C).ServerReStartPlayer();
				}
			}

			// If the jail is full, start up the execution
			//log("Jail count: Red"@NumPawnsJailed[0]$", Blue"@NumPawnsJailed[1]);
			if (NumPawnsJailed[0] >= Level.Game.GameReplicationInfo.Teams[0].Size)
				ExecutionEvent(Level.Game.GameReplicationInfo.Teams[0], LastKilled.Pawn);
			if (NumPawnsJailed[1] >= Level.Game.GameReplicationInfo.Teams[1].Size)
				ExecutionEvent(Level.Game.GameReplicationInfo.Teams[1], LastKilled.Pawn);
		}

		// Check on the MadCow Hunt
		if ( MadCowHuntStartTime != 0 && (NumMadCowsActive <= 0 || MadCowHuntStartTime + MadCowHuntDuration <= Level.TimeSeconds) )
		{
			// end the MadCow Hunt
			MadCowHuntStartTime = 0;
			BroadcastLocalizedMessage(class'JailMessage', 6);
		}

		// now do the super
		Super.Timer();
	}
}

// prevent the extra "Match has begun" message after executions
state ResumeAfterExecution extends MatchInProgress
{
	ignores PawnJailed, RestartPlayer;

	event BeginState();

	// Score points, reset players, destroy pawns and start next round
	event EndState()
	{
		local Controller C;
		local Pawn P;
		local Actor A;
		local ExecutionOverTrigger ET;

		if (OurGibber != None)
		{
			OurGibber.Destroy();
			OurGibber = None;
		}

		if (DyingTeam.TeamIndex == 0)
			TriggerEvent(JBGameRules(LevelRules).ExecutionOverEventRed, DyingTeam, None);
		if (DyingTeam.TeamIndex == 1)
			TriggerEvent(JBGameRules(LevelRules).ExecutionOverEventBlue, DyingTeam, None);
	
		// score a point
		ScoringTeam.Score+= 1;

		// Reset the jail pawns
		NumPawnsJailed[0]=0;
		NumPawnsJailed[1]=0;

		// See if this point causes a win
		if (EndGameScorer.Team == ScoringTeam)
			CheckScore(EndGameScorer);
		else // Enemy suicides or teamkills can cause a win for the other team
		{
			// find some random guy on the scoring team and see if the match should end
			C = Level.ControllerList;
			while (C != None)
			{
				if (C.PlayerReplicationInfo.Team == ScoringTeam)
				{
					CheckScore(C.PlayerReplicationInfo);
					break;
				}
				C = C.NextController;
			}
		}

		// If not, then prepare for next round
		if (!bGameEnded)
		{
			// Do execution cleanup
			foreach AllActors(class'Actor', A, 'ExecutionCleanup')
				A.Destroy();

			// Reset all players and destroy their pawns
			// This will make them respawn combined with force respawn in MatchInProgress
			C = Level.ControllerList;
			while (C != None)
			{
				if (C.Pawn != None)
					P = C.Pawn;
				else
					P = None;
				if (JBPlayer(C) != None)
					C.Reset();
				if (Bot(C) != None)
					C.PlayerReplicationInfo.Deaths = 0;
				if (P != None)
					if (P.Health > 0)
						P.Destroy();
				C = C.NextController;
			}
		}
	}
Begin:
	Sleep(5);
	GotoState('PostResumeExecution');
}

state PostResumeExecution extends MatchInProgress
{
	event BeginState();
}

state Executing extends MatchInProgress
{
	ignores PawnJailed, RestartPlayer;

	// Force a player to watch the execution
	function ForceExecutionView(JBPlayer P)
	{
		P.ClientWatchExecution(ExecCamera);
		P.ClientSetViewTarget(ExecCamera);
		P.SetViewTarget(ExecCamera);
	}

	// Check all the controllers, force any players to watch the execution
	function ScanForExecutionView()
	{
		local Controller C;
	
		C = Level.ControllerList;
		while (C != None)
		{
			if (JBPlayer(C) != None)
				if (C.GetStateName() != 'WatchingExecution' || PlayerController(C).ViewTarget != ExecCamera)
					if (C.PlayerReplicationInfo.Team != DyingTeam || C.Pawn == None || C.Pawn.Health <= 0)
						ForceExecutionView(JBPlayer(C));
			C = C.NextController;
		}
	}
	
	function DisarmLosers()
	{
		local Controller C;

		C = Level.ControllerList;
		while (C != None)
		{
			if (P2Pawn(C.Pawn) != None && C.PlayerReplicationInfo.Team == DyingTeam)
			{
				C.Pawn.bCanPickupInventory=false;
				P2Pawn(C.Pawn).DestroyAllInventory();
			}
			C = C.NextController;
		}
	}

	// Let everyone get a good view of the execution
	event BeginState()
	{
		DisarmLosers();
		ScanForExecutionView();
	}

	// Wait for the execution, once all pawns are killed move on to the next round
	event Timer()
	{
		local Pawn P;
		local bool bStillAlive;

		Global.Timer(); // don't call super, we don't need anything 'funny' to happen right now

		// count up all the pawns that still need to be killed before the execution is "over"
		ForEach DynamicActors(class'Pawn', P)
			if (P.Health > 0 && P.GetTeam() == DyingTeam)
				bStillAlive=true;

		// check for a better execution view
		ExecCamera = GetExecutionCamera(DyingTeam);

		// If we missed anyone, stop and make them watch the execution
		ScanForExecutionView();

		if (!bStillAlive)
		{
			//WaitNextRoundTime=0;
			GotoState('ResumeAfterExecution');
		}
	}
}

defaultproperties
{
	GoalScore=3

	//WaitForNextRound=5
	bUseMadCow=true
	bJailCampMadCow=false
	JailCampThreshold=300
	JailCampWarning=10
	MadCowHuntDuration=60
	ReleaseProtectionDuration=5

	bScoreTeamKills=false

	MadCowHeadMesh="stuff.stuff1.CowHead"
	//MadCowHeadSkin=Texture'WeaponSkins.cowhead_256'

	GameName="JailBreak"
	PlayerControllerClassName="P2JailBreak.JBPlayer"
	//PlayerControllerClassName="MultiStuff.xMpPlayer"
	HUDType="P2Jailbreak.JBHUD"
	ScoreBoardType="P2JailBreak.JBScoreboard"
	MatchIntroClassName="MultiGame.TeamIntro"

	MapNameGameCode="j"	// must be lower case!
	MapListType="P2Jailbreak.JBMapList"
	GameReplicationInfoClass=Class'MultiBase.MpGameReplicationInfo'
	DeathMessageClass=class'MultiGame.xDeathMessage'
	MutatorClass="MultiGame.xMutator"
	LevelRulesClass=class'P2Jailbreak.JBGameRules'
	SettingsMenuType="P2JailBreak.JBSettingsSClient"

	GameBaseEquipment[0]=(weapclass=class'Inventory.UrethraWeapon')
	GameBaseEquipment[1]=(weapclass=class'Inventory.FootWeapon')
	GameBaseEquipment[2]=(weapclass=class'Inventory.BatonWeapon')
	GameBaseEquipment[3]=(weapclass=class'Inventory.PistolWeapon')
	GameBaseEquipment[4]=(weapclass=class'Inventory.MachineGunWeapon')

	MadCowPrizes[0]=(prizeclass=class'Inventory.KevlarInv',chance=1)
	MadCowPrizes[1]=(prizeclass=class'Inventory.BodyArmorInv',chance=0.5)
	MadCowPrizes[2]=(prizeclass=class'Inventory.CrackInv',chance=1)
	MadCowPrizes[3]=(prizeclass=class'Inventory.RadarInv',chance=0.75)
}