// JailMessage.uc
// Switch 0: Entire team jailed
// 	RelatedPRI_1 is the scorer
//	OptionalObject is the TeamInfo of the scoring team
// Switch 1: Jail release triggered
//	RelatedPRI_1 is the triggerer
//	OptionalObject is the TeamInfo of the released team
// Switch 2: Suicide caused a point for the other team
//	RelatedPRI_1 is the suicider
// 	OptionalObject is the TeamInfo of the scoring team
// Switch 3: just a plain scoring message
//	OptionalObject is the TeamInfo of the scoring team
// Switch 4: Mad Cow Hunt is on
// Switch 5: Mad Cow was fragged
//	RelatedPRI_1 is the player who fragged the MadCow
// Switch 6: Mad Cow hunt over

class JailMessage extends CriticalEventPlus;

var(Message) localized string TeamWasJailed[2];
var(Message) localized string JailReleaseTriggered[2];
var(Message) localized string SuicideCausedEnemyPoint[2];
var(Message) localized string TeamScoreMessage[2];
var(Message) localized string MadCowHunt;
var(Message) localized string MadCowFragged;
var(Message) localized string MadCowOver;

var sound CowHuntStartSound;
var sound CowHuntFragSound;
var sound CowHuntEndSound;

static simulated function ClientReceive( 
	PlayerController P,
	optional int Switch,
	optional PlayerReplicationInfo RelatedPRI_1, 
	optional PlayerReplicationInfo RelatedPRI_2,
	optional Object OptionalObject
	)
{
	local int YouOrThem;

	Super.ClientReceive(P, Switch, RelatedPRI_1, RelatedPRI_2, OptionalObject);

	if (TeamInfo(OptionalObject) != None &&
		MpPlayer(P) != None &&
		P.PlayerReplicationInfo != None ||
		P.PlayerReplicationInfo.Team != None )
	{
		if (P.PlayerReplicationInfo.Team.TeamIndex != TeamInfo(OptionalObject).TeamIndex)
			YouOrThem = 1;

		switch (Switch)
		{
			// team scores
			case 0:
				MpPlayer(P).PlayAnnouncement(MpTeamInfo(OptionalObject).default.TeamScoreSound,1, true);
				break;
			case 2:
				MpPlayer(P).PlayAnnouncement(MpTeamInfo(OptionalObject).default.TeamScoreSound,1, true);
				break;
			case 3:
				MpPlayer(P).PlayAnnouncement(MpTeamInfo(OptionalObject).default.TeamScoreSound,1, true);
				break;
			case 4:
				MpPlayer(P).PlayAnnouncement(Default.CowHuntStartSound,1, true);
				break;
			case 5:
				MpPlayer(P).PlayAnnouncement(Default.CowHuntFragSound,1, true);
				break;
			case 6:
				MpPlayer(P).PlayAnnouncement(Default.CowHuntEndSound,1, true);
				break;
		}
	}
}

static function string GetString(
	PlayerController P,
	optional int Switch,
	optional PlayerReplicationInfo RelatedPRI_1, 
	optional PlayerReplicationInfo RelatedPRI_2,
	optional Object OptionalObject
	)
{
	local int YouOrThem;

	if (TeamInfo(OptionalObject) != None &&
		MpPlayer(P) != None &&
		P.PlayerReplicationInfo != None ||
		P.PlayerReplicationInfo.Team != None )
	{
		if (P.PlayerReplicationInfo.Team.TeamIndex != TeamInfo(OptionalObject).TeamIndex)
			YouOrThem = 1;

		switch (Switch)
		{
			// Team scores
			case 0:
				return RelatedPRI_1.PlayerName @ Default.TeamWasJailed[YouOrThem];
				break;
			// Release triggered
			case 1:
				return RelatedPRI_1.PlayerName @ Default.JailReleaseTriggered[YouOrThem];
				break;
			// Suicide score
			case 2:
				return RelatedPRI_1.PlayerName @ Default.SuicideCausedEnemyPoint[YouOrThem];
				break;
			// Just a plain score
			case 3:
				return Default.TeamScoreMessage[YouOrThem];
				break;
			// Start up the MadCow hunt
			case 4:
				return Default.MadCowHunt;
				break;
			// MadCow was fragged
			case 5:
				return RelatedPRI_1.PlayerName @ Default.MadCowFragged;
				break;
			// End of the MadCow hunt
			case 6:
				return Default.MadCowOver;
				break;
		}
	}
}

defaultproperties
{
	TeamWasJailed(0)="fragged the last loser on the enemy team!"
	TeamWasJailed(1)="fragged the last loser on your team!"
	JailReleaseTriggered(0)="just freed your teammates!"
	JailReleaseTriggered(1)="just freed the enemy team!"
	SuicideCausedEnemyPoint(0)="treacherously scored a point for your team!"
	SuicideCausedEnemyPoint(1)="treacherously scored a point for the enemy!"
	TeamScoreMessage(0)="Your team scored!"
	TeamScoreMessage(1)="The enemy team scored!"
	MadCowHunt="The MadCow Hunt is on!"
	MadCowFragged="fragged a MadCow!"
	MadCowOver="The MadCow Hunt is over!"

	CowHuntStartSound=sound'AmbientSounds.alarm1'
	CowHuntFragSound=sound'MpAnnouncer.AnnouncerYouWon2'
	CowHuntEndSound=sound'LevelSounds.train_cross_bell_LP'
}