// JailRelease.uc
// TeamTrigger that tells the whole world when we're activated
class JailRelease extends TeamTrigger;

var() Sound JailReleaseSound;
var() array<Name> JailZoneTags; // to be utilized later
var() StaticMesh OurStaticMesh;

// We want these to show up on the radar. However, they will not show up if bHidden is true.
// Instead, set bHidden to false and set drawtype to none.
// The trigger will be hidden but will still show up on the fish radar.
simulated event PostBeginPlay()
{
	if (bHidden)
	{
		bHidden=false;
		SetDrawType(DT_None);
	}
	else
	{
		bHidden=false;
		SetDrawType(DT_StaticMesh);
		SetStaticMesh(OurStaticMesh);
	}
	Super.PostBeginPlay();
}

// A special state that allows other actors to "trigger" the jail release.
// In this event, the jail release will display the message and then trigger any other triggers set up by Event.
// For an example see the urinal in Splinter Foundry.
// When the player pisses enough on the urinal, it will trigger this actor, which will then broadcast the message and
// open the door.
state() JR_OtherTriggerTriggers
{
	function bool IsRelevant(actor Other)
	{
		local Pawn P;
		local int TheirTeam;
	
		if (Pawn(Other) == None)
			return false;
		else
			P = Pawn(Other);
	
		if (P.PlayerReplicationInfo.Team == None)
			return false;
		else
			TheirTeam = P.PlayerReplicationInfo.Team.TeamIndex;
	
		if (TheirTeam != OurTriggeringTeam)
			return false;
		else
			return true;		
	}

	function Trigger( actor Other, pawn EventInstigator )
	{
		//log("Trigger called. Other:"@Other@"EventInstigator:"@EventInstigator);
		if (IsRelevant(EventInstigator))
			TriggerEvent(Event, self, EventInstigator);
	}
}

event TriggerEvent( Name EventName, Actor Other, Pawn EventInstigator )
{
	local int i;

	//log(self@"called TriggerEvent. EventName:"@EventName@"Other:"@Other@"EventInstigator:"@EventInstigator);

	Super.TriggerEvent(EventName, Other, EventInstigator);

	BroadcastLocalizedMessage(class'JailMessage',1,EventInstigator.PlayerReplicationInfo,None,EventInstigator.GetTeam());
	PlaySound(JailReleaseSound);
	/*if (JailBreakGame(Level.Game) != None)
		for (i=0;i<JailZoneTags.Length;i++)
			JailBreakGame(Level.Game).TriggerReleaseProtection(JailZoneTags[i]);*/
}

event Tick(float Deltatime)
{
	if (Physics == PHYS_Rotating)
		SetRotation(Rotation + RotationRate);
}

defaultproperties
{
	bAlwaysRelevant=true
	bHidden=false
	drawtype=DT_StaticMesh
	StaticMesh=StaticMesh'dj-protostuff.sign_rws_nopole'
	OurStaticMesh=StaticMesh'dj-protostuff.sign_rws_nopole'
	JailReleaseSound=Sound'MiscSounds.Props.MetalHitsGround3'
	Physics=PHYS_Rotating
	RotationRate=(Yaw=360)
}