// JailZone.uc
// Zone that defines a jail.
class JailZone extends ZoneInfo;

// I tried to get rid of all this crap below but we need it to keep track of the "mad cow list".
// It notifies the game whenever someone enters or leaves this zone.
// Otherwise, just a regular zoneinfo.

const bDebugLog=False;

var array<Pawn> JailedList;
var array<Pawn> UnJailedList;

// When pawns were being spawned inside the jail, ActorEntered was being called before the pawn's information could be
// updated (such as team and whatnot). This simply gathers up all the pawns that are being spawned and tells the gameinfo
// on the next tick.
function AddToJailedList(Pawn P)
{
	if (bDebugLog)
		log(P@"added to jailed list");
	JailedList.Insert(0,1);
	JailedList[0] = P;
}

function AddToUnJailedList(Pawn P)
{
	if (bDebugLog)
		log(P@"added to unjailed list");
	UnJailedList.Insert(0,1);
	UnJailedList[0] = P;
}

// when an actor enters or leaves, add them to our list
event ActorEntered(actor Other)
{
	local Pawn P;

	Super.ActorEntered(Other);

	if (Pawn(Other) == None)
		return;
	else
		P = Pawn(Other);

	if (JBPlayer(P.Controller) != None)
		if (JBPlayer(P.Controller).OurReleaseProtection != None)
			JBPlayer(P.Controller).OurReleaseProtection.Destroy();

	if (bDebugLog)
		log(P@"entered jail zone"@Self);
	AddToJailedList(P);
}

event ActorLeaving(actor Other)
{
	local Pawn P;

	Super.ActorLeaving(Other);

	if (Pawn(Other) == None)
		return;
	else
		P = Pawn(Other);

	if (bDebugLog)
		log(P@"left jail zone"@Self);

	// Do release protection, but only if they're out of jail
	if (JBPlayer(P.Controller) != None && P.Health > 0) // && JailZone(Other.PlayerReplicationInfo.PlayerZone) == None)
	{
		JBPlayer(P.Controller).SetupReleaseProtection(JailBreakGame(Level.Game).ReleaseProtectionDuration);
	}
	AddToUnJailedList(P);
}

// tell the gameinfo about the pawns who have entered or left the jail
event Tick(Float DeltaTime)
{
	local int i;

	for (i=0; i<JailedList.Length; i++)
	{
		JailBreakGame(Level.Game).PawnJailed(JailedList[i]);
		if (bDebugLog)
			log("told the game about"@jailedlist[i]@"being jailed");
	}
	for (i=0; i<UnJailedList.Length; i++)
	{
		JailBreakGame(Level.Game).PawnUnJailed(UnJailedList[i]);
		if (bDebugLog)
			log("told the game about"@unjailedlist[i]@"being unjailed");
	}

	JailedList.Length=0;
	UnJailedList.Length=0;

	Super.Tick(DeltaTime);
}

defaultproperties
{
	bStatic=false // so Tick can be called
}
